package com.unis.message.server.controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.message.common.vo.MessageVO;
import com.unis.message.server.service.IMessServer;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@RequestMapping("/mess")
@Slf4j
@Api(value = "短信", tags = "短信")
public class MessController {
	
	@Autowired
	private IMessServer iMessServer;

	@ApiOperation(value = "发送短信", notes = "参数：短信实体信息,验证码类型短信，正文可为null")
    @PostMapping(value = "/sendMessage")
    public ResponseWrapper send(@RequestBody MessageVO messageVO) {
        try {
        	String result =iMessServer.sendMess(messageVO);
            return ResponseWrapper.success(result);
        } catch (Exception e) {
        	 //e.printStackTrace();
            log.error("发送消息，发生异常："+e.getMessage());
            return ResponseWrapper.error("发送消息失败");
        }
    }
	
	
	@ApiOperation(value = "验证验证码", notes = "参数：手机号及验证码，验证码有效期15分钟")
    @PostMapping(value = "/verify/{mobile}/{code}")
    public ResponseWrapper verify(@PathVariable String mobile,@PathVariable String code) {
        try {
        	boolean result =iMessServer.verify(mobile,code);
        	if(result) {
        		return ResponseWrapper.success(200, "验证成功", result);
        	}
            return ResponseWrapper.success(200, "验证码错误或已过期", result);
        } catch (Exception e) {
        	 //e.printStackTrace();
            log.error("发送消息，发生异常："+e.getMessage());
            return ResponseWrapper.error("获取失败");
        }
    }
}
